==> pvfs-1.3.2.tgz: pvfs-1.3.2/mgr/meta/get_root_dir.c <==
/*
/* get_root_dir.c copyright (c) 1996 Rob Ross, all rights reserved.
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License as published
	by the Free Software Foundation; either version 2 of the License, or
	any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of 
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
	General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
	Contact:  Rob Ross  	rbross@parl.eng.clemson.edu
				 Matt Cettei mcettei@parl.eng.clemson.edu

/*/

/*
/* GET_ROOT_DIR.C - 
/*
/*/

/*
 * $Log: get_root_dir.c,v $
 * Revision 1.2  1997/10/28 19:00:17  pvfs
 * added license
 *
 * Revision 1.1  1997/01/16 16:33:57  mcettei
 * Initial revision
 *
 *
/*/

static char get_root_dir_c[] = "$Header: /projects/pvfs/pvfs-working/mgr/meta/RCS/get_root_dir.c,v 1.2 1997/10/28 19:00:17 pvfs Exp $";
/* The getrootdir function will take the file name from the request, */
/* read the .pvfsdir file, and write the root directory name to      */
/* rootbuf.  The function returns 0 on success and -1 on failure.    */

#include <errno.h>
#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/file.h>
#include <fcntl.h>
#include <unistd.h>
#include <string.h>
#include <meta.h>
#include <req.h>

/* GLOBALS */
extern int errno;

int get_root_dir(char * fname, char* rootbuf) {
dmeta dir;
int i, length, fd;
char temp[256];

   strcpy(temp, fname);
   length = strlen(temp);
   while (temp[length] != '/') {
      temp[length] = 0;
      length--;
   }
   strcat(temp, ".pvfsdir");
   if ((fd = open(temp, O_RDWR)) < 1) {
      perror("Error opening dot file");
      return(-1);
   }
   if ((i = read(fd, &dir, sizeof(dmeta))) < 1) {
      perror("Error reading dotfile");
      return(-1);
   }
   length = dir.fn_len;
   if ((i = read(fd, rootbuf, length*sizeof(char))) < 1) {
      perror("Error read root name");
      return(-1);
   }
	if (rootbuf != NULL)  {
		if (rootbuf[length - 1] != '/') {
			rootbuf[length] = '/';
			rootbuf[length +1] = 0;
		} else rootbuf[length] = 0;
	}	
	close(fd);
   return(0);

}

int get_rd_ino(char * fname, char* rootbuf, ino_t *fs_ino_p) {
dmeta dir;
int i, length, fd;
char temp[256];

   strcpy(temp, fname);
   length = strlen(temp);
   while (temp[length] != '/') {
      temp[length] = 0;
      length--;
   }
   strcat(temp, ".pvfsdir");
   if ((fd = open(temp, O_RDWR)) < 1) {
      perror("Error opening dot file");
      return(-1);
   }
   if ((i = read(fd, &dir, sizeof(dmeta))) < 1) {
      perror("Error reading dotfile");
      return(-1);
   }
   length = dir.fn_len;
	*fs_ino_p = dir.fs_ino;
   if (rootbuf && (i = read(fd, rootbuf, length*sizeof(char))) < 1) {
      perror("Error read root name");
      return(-1);
   }
	if (rootbuf != NULL) {
		if (rootbuf[length - 1] != '/') {
			rootbuf[length] = '/';
			rootbuf[length +1] = 0;
		} else rootbuf[length] = 0;
	}	
	close(fd);
   return(0);
}

==> pvfs-1.4.2.tgz: pvfs-1.4.2/mgr/meta/get_root_dir.c <==
/*
 * get_root_dir.c copyright (c) 1996 Rob Ross, all rights reserved.
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License, or
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * Contact:  Rob Ross  	rbross@parl.eng.clemson.edu
 * 
 */


static char get_root_dir_c[] = "$Header: /projects/cvsroot/pvfs/mgr/meta/get_root_dir.c,v 1.2 1999/08/13 23:26:24 rbross Exp $";

/* The getrootdir function will take the file name from the request, */
/* read the .pvfsdir file, and write the root directory name to      */
/* rootbuf.  The function returns 0 on success and -1 on failure.    */

#include <errno.h>
#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/file.h>
#include <fcntl.h>
#include <unistd.h>
#include <string.h>
#include <meta.h>
#include <req.h>

/* GLOBALS */
extern int errno;

int get_root_dir(char * fname, char* rootbuf)
{
	dmeta dir;
	int i, length, fd;
	char temp[256];

   strcpy(temp, fname);
   length = strlen(temp);
   while (temp[length] != '/') {
      temp[length] = 0;
      length--;
   }
   strcat(temp, ".pvfsdir");
   if ((fd = open(temp, O_RDWR)) < 1) {
      perror("Error opening dot file");
      return(-1);
   }
   if ((i = read(fd, &dir, sizeof(dmeta))) < 1) {
      perror("Error reading dotfile");
      return(-1);
   }
   length = dir.fn_len;
   if ((i = read(fd, rootbuf, length*sizeof(char))) < 1) {
      perror("Error read root name");
      return(-1);
   }
	if (rootbuf != NULL)  {
		if (rootbuf[length - 1] != '/') {
			rootbuf[length] = '/';
			rootbuf[length +1] = 0;
		} else rootbuf[length] = 0;
	}	
	close(fd);
   return(0);

}

int get_rd_ino(char * fname, char* rootbuf, ino_t *fs_ino_p) {
dmeta dir;
int i, length, fd;
char temp[256];

   strcpy(temp, fname);
   length = strlen(temp);
   while (temp[length] != '/') {
      temp[length] = 0;
      length--;
   }
   strcat(temp, ".pvfsdir");
   if ((fd = open(temp, O_RDWR)) < 1) {
      perror("Error opening dot file");
      return(-1);
   }
   if ((i = read(fd, &dir, sizeof(dmeta))) < 1) {
      perror("Error reading dotfile");
      return(-1);
   }
   length = dir.fn_len;
	*fs_ino_p = dir.fs_ino;
   if (rootbuf && (i = read(fd, rootbuf, length*sizeof(char))) < 1) {
      perror("Error read root name");
      return(-1);
   }
	if (rootbuf != NULL) {
		if (rootbuf[length - 1] != '/') {
			rootbuf[length] = '/';
			rootbuf[length +1] = 0;
		} else rootbuf[length] = 0;
	}	
	close(fd);
   return(0);
}
